#
# spec file for package LaTeXML
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           LaTeXML
Version:        0.8.8
Release:        1.3
License:        SUSE-Public-Domain
Group:          Productivity/Publishing/TeX/Utilities
Summary:        TeX and LaTeX to XML translator
URL:            http://dlmf.nist.gov/LaTeXML/
Source:         https://github.com/brucemiller/LaTeXML/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildArch:      noarch
%define perl_modules perl(Archive::Zip) perl(DB_File) perl(File::Which) perl(Getopt::Long) perl(IO::String) perl(Image::Size) perl(JSON::XS) perl(LWP::Protocol::https) perl(Parse::RecDescent) perl(Text::Unidecode) perl(Test::Simple) perl(Time::HiRes) perl(URI) perl(XML::LibXML) perl(XML::LibXSLT) perl(Pod::Find) perl(UUID::Tiny)
BuildRequires:  %perl_modules
BuildRequires:  perl
BuildRequires:  perl-macros
Requires:       %perl_modules
Requires:       perl(%{name})
%{perl_requires}
Recommends:     ImageMagick
Recommends:     texlive

%description
LaTeXML is a TeX & LaTeX to XML, HTML, MathML, ePub, JATS, ... converter.

%package -n perl-%{name}
Summary:        Perl files for %{name}
Requires:       %perl_modules
%{perl_requires}

%description -n perl-%{name}
Perl files for %{name}

%prep
%setup -q

%build
sed -i 's@\#\!/usr/bin/env perl@\#\!/usr/bin/perl@' bin/*
%{__perl} Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
%perl_make_install
%perl_process_packlist

%check
make test %{?_smp_mflags}

%files
%defattr(-,root,root)
%{_bindir}/latexml
%{_bindir}/latexmlc
%{_bindir}/latexmlfind
%{_bindir}/latexmlmath
%{_bindir}/latexmlpost
%{_mandir}/man1/*

%files -n perl-%{name}
%{_mandir}/man3/%{name}*
%{perl_vendorlib}/*

%changelog
* Mon Feb 26 2024 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- Update to version 0.8.8:
  * This release addresses a large variety of usability, fidelity, robustness,
    portability and output-quality issues.
  * breaking change: ltx:inline-para has been renamed
    ltx:inline-logical-block
  * Improved CSS, html, accessibility affecting
  * framing, position & rotation, color
  * figure/subfigure grouping
  * MathML (closer to MathML Core)
  * avoid gratuitous math mode (simple sub/superscripts); mathvariant
  * option to avoid InvisibleTimes, when not certain (--noinvisibletimes)
  * Improved emulation of TeX internals
  * affecting registers, \chardef, accents, intarray, tracing
  * More TeX-like "scanning" of tokens affecting
  * expansion, input,
  * alignments (\halign,tabular)
  * improved block mode processing
  * affecting \parbox, {minipage}, \centering, \raggedright/left
  * More consistent set of block elements:
  * ltx:block, ltx:logical-block, ltx:sectional-block,
  * along with their inline variants:
  * ltx:inline-block, ltx:inline-logical-block, ltx:inline-sectional-block
  * breaking change: ltx:inline-para has been renamed
    ltx:inline-logical-block
  * Improvements to processing alignments (\halign, tabular),
  * more TeX-like (processing templates, spacing)
  * Improved processing of images, graphics, svg generation
  * image post-processing
  * pgf, tikz, pgfplots, tikz-cd
  * initial support for Vietnamese, t5enc
  * improved Windows portability
  * improved schema documentation
  * Improvements to test cases.
  * New bindings: boxedminipage, cmap, ifdraft, marginnote, tikz-cd.
  * Improvements to bindings: aa, aas, algorithm2e, amsmath, amsthm,
    cleverref, comment, csquotes, elsarticle, enumitem, expl3, framed,
    hyperref, hyperxmp, IEEEtran, lineno, listing, longtable, mn2e, nicefrac,
    ntheorem, pdfpages, pgfmath, pgfplots, rotating, srcltx, sidecap,
    subcaption, subfiles, thmtools, tikz, url, xfrac, xypic.
* Mon Dec 26 2022 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- Update to version 0.8.7:
  * This release addresses a large variety of usability, fidelity, robustness,
    portability and output-quality issues.
  * MathML (mostly) conforms to MathML Core, with more consistent spacing
  * More TeX-like dimensions & computation; font metrics used for (approximate)
    sizing
  * Improvements to HTML5, ePub, JATS, CSS, frontmatter
  * Improvements to graphics and SVG
  * support for \includegraphics alt key
  * updated schema to SVG 1.1 2nd ed (roughly)
  * xy now supported, generating SVG
  * Windows & MacOS related improvements
  * Support for attributes in foreign namespaces; conversion to data-XXX
    attributes in html
  * Default to lang="en" unless told otherwise
  * title attributes now use UnicodeMath; also --unicodemath math format option
  * Enhancements to latexml.sty (see the code for details)
  * Package keywords
  - breakuntex, nobreakuntex: control linebreaks in tex attribute
  - dpi=number, magnify=number, upsample=number, zoomout=number: image
    conversion controls
  - tokenlimit=number, iflimit=number, absorblimit=number,
    pushbacklimit=number: limit execution
  * \LaTeXMLversion, \LaTeXMLrevision, \LaTeXMLfullversion: show the LaTeXML
    version
  * \lxRegisterNamespace{prefix}{uri} : register a namespace w/ prefix
  * \lxAddAnnotation{keyvals} : add annotation attributes to current node
  * \lxWithAnnotation{keyvals}{thing} : Typeset thing with annotation attributes
  * New bindings: amsaddr, atveryend, auxhook, babel, bbding, bezier,
    bigintcalc, bitset, bookmark, doi, ed, expl3, fancyvrb, feynmf, fixme,
    gettitlestring, ifetex, ifsym, iftex, ijcai, infwarerr, intcalc,
    kvdefinekeys, kvoptions, kvsetkeys, l3keys2e, ltxcmds, nomencl, overpic,
    pdftexcmds, refcount, subeqn, subeqnarray, tcolorbox, tikzbricks, upquote,
    xurl, xy, xypic  and beamer.cls
  * Improvements to bindings: algorithm2e, amsmath, amsthm, babel, csquotes,
    deluxetable, enumitem, glossaries, hyperref, longtable, lstings, mathtools,
    physics, revtex, svmult, thmtools.
* Tue Jul 12 2022 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- Add depndency on perl(UUID::Tiny)
- Recommend instead of requiring ImageMagick and texlive
* Fri Jun 17 2022 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- Remove the _service file
- Simplify call to sed
* Thu Oct 21 2021 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- Update to version 0.8.6:
  * This release addresses a large variety of usability, fidelity, robustness,
    portability and output-quality issues.
  * The Error handling system now produces both a log file (with details) and
    a brief term-styled output on STDERR.
  * Even when Fatal errors are encountered, the document "so far" is returned.
  * Many improvesments were made to mimicing more closely TeX's commands
    and LaTeX internals, along with more testcases to detect regressions.
  * Major revision of Alignments (\halign, tabular, etc) to be more TeX-like,
    with respect to the timing of expansion.
  * Many Errors and Fatals are now fixed or avoided.
    The Windows platform is much better supported.
  * Ouput to HTML, CSS, JATS, TEI have been updated, modernized and validated.
    tikz/pgf and picture environment output is improved.
  * new bindings: actuarialangle.sty, adjustbox.sty, diagbox.sty, elsart_support_core.sty,
    espcrc.sty, fancybox.sty, filehook.sty, hepunits.sty, hypcap.sty, ifplatform.sty,
    mathabx.sty, minimal.cls, pgfplotstable.sty, prettyref.sty, proof.sty, proofwiki.sty,
    psfrag.sty, SIunits.sty, slashbox.sty, standalone.cls, standalone.sty, xfrac.sty
* Sun Dec 13 2020 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- Update to version 0.8.5:
  * Acknowledging his many contributions to LaTeXML,
    Deyan Ginev is recognized as a co-developer.
  * A large variety of robustness, fidelity and portability patches:
    reduced errors & warnings, more consistent ids, formatting,
  * Improved TeX fidelity, including l3kernel simulation,
    while maintaining backwards compatibility (latex2, 2e).
  * Enhanced declaration & preservation of math semantics,
    improved tools for parallel markup
    Enhanced semantics of siunitx, physics
  * improved support for lists (enumitem), theorems, cleveref, listings, nicefrac,
    multiple bibliographies, tikz/pgf, multiple bibliographies, JATS,
    multi-document site generation; including supporting more options.
  * "Raw" style files now processed by default when in source document's directory
  * new bindings: aastex63.cls, aipproc.sty, physics.sty,
    pgfmathcalc.code.tex, pgfutil-common.tex
  * Experimental features:
  * math lexemes: exports math as non-semantic tokens for data mining experiments;
    simplfied format avoid introducing inferred semantics
  * accessibility annotations
* Sun Nov 15 2020 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- Add dependency on Pod::Find
* Sat Jun 29 2019 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- Update to version 0.8.4:
  * Various fidelity and robustness improvements, along with more test cases
  * Improved source locators for debugging and other purposes.
  * More flexible backmatter, allowing multiple bibliographies, indices, etc.
  * Improvements to math lexer
  * Support for Chocolatey package manager
  * More generalized support for lists of (contents, tables, figures, etc)
  * New bindings: aipcheck.tex, aipproc.cls, bibunits.sty, blindtext.sty,
    calrsfs.sty, chapterbib.sty, chngcntr.sty, csquotes.def, csquotes.sty,
    fancyheadings.sty, footnote.sty, mathdots.sty, nopageno.sty, PoS.cls,
    quantumarticle.cls, remreset.sty, sidecap.sty, subfiles.(cls|sty),
    tcilatex.tex, thm-restate.sty, twoopt.sty, underscore.sty, undertilde.sty,
    varioref.sty, varwidth. styvmargin.sty
  1de821d0df8c88041ee10820188f33feac77d5618de4c0798a296a425f4e2637-------------------------------------------------------------------
* Sun Dec  9 2018 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- Add requires for the perl package
* Sun Dec  9 2018 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- Don't use "/usr/bin/env perl" in shebang
* Thu Dec  6 2018 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- Add group
* Thu Dec  6 2018 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- Add perl-LaTeXML subpackage
* Wed Dec  5 2018 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- Use _service
* Wed Aug 15 2018 jaime.marquinez.ferrandiz@fastmail.net
- Update to version 0.8.3:
  - Way too long between releases...
  - Too many bug fixes, fidelity improvements and enhancements to list.
  - (nominal) support for TEI format
  - New Bindings: aastex61.cls, aastex6.cls, accents.sty, acmart.cls,
    aecompl.sty, algorithm2e.sty, appendix.sty, cases.sty,
    cleveref.sty, csquotes.sty, empheq.sty, endnotes.sty, enumitem.sty,
    etex.sty, etoolbox.sty, flowchart.sty, flushend.sty,
    french.ldf, gensymb.sty, icml2018.sty (& others), ieeeconf.cls, IEEEtran.cls,
    jheppub.sty, lastpage.sty, lipsum.sty, makecell.sty,
    microtype.sty, mleftright.sty, mnras.cls, moderncv.cls,
    newfloat.sty, newtxmath.sty, newtxtext.sty, pdfpages.sty,
    pgfmath.code.tex, pzd.fontmap, ragged2e.sty, revtex4-1.cls,
    sectsty.sty, siunitx.sty, siunitx.sty.bak, stfloats.sty,
    subcaption.sty, svjour3.cls, tablefootnote.sty, textcase.sty,
    thmtools.sty, titlesec.sty, titling.sty, todonotes.sty,
    tracefnt.sty, turing.sty, utf8x.def, wiki.sty, xkeyval.sty,
    xkvview.sty
  - 2 Experimental features:
  * xpath source locators: for locating the origin of the XML in the TeX sources.
  * math lexemes: textual encoding of mathematics for data mining studies.
    Please consult the mailing list for more information.
